use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( examples lib script t xt ) );
__DATA__
CPAN
Changes
Dist
Doherty
Etheridge
Fredric
Gardner
Graham
Karen
Kent
Knop
Mark
Mengué
Mike
Nelo
Olivier
Onyiah
Plugin
Test
Zilla
doherty
dolmen
ether
haarg
irc
kentfredric
lib
mgardner
mike
nelo
